@@ -3,6 +3,7 @@ import os
 from pathlib import Path
 
 import click
+import pkg_resources
 
 from src.client import vendor, RestClient
 
@@ -27,8 +28,8 @@ def lm_cli(ctx):
 
 
 @lm_cli.command()
-@click.option("--vendor_name", required=True, help="name of vendor")
-@click.option("--email", required=True, help="vendor's email address")
+@click.option("-v", "--vendor_name", required=True, help="name of vendor")
+@click.option("-e", "--email", required=True, help="vendor's email address")
 @click.pass_context
 def create_vendor(ctx, vendor_name, email):
     rc = ctx.obj["rc"]
@@ -37,39 +38,39 @@ def create_vendor(ctx, vendor_name, email):
 
 
 @lm_cli.command()
-@click.option("--vendor_name", required=True, help="name")
+@click.option("-v", "--vendor_name", required=True, help="name")
 @click.pass_context
 def get_customers_of_a_vendor(ctx, vendor_name):
     rc = ctx.obj["rc"]
     rc.get(rc.url + "/licenses/partners/%s" % vendor_name)
 
 
-def format_license_input(subscription, quota, sites):
-    licenses, lic = [], {}
-    if subscription:
-        lic["subscription"] = {"time": subscription}
-    if quota:
-        lic["quota"] = {"users": quota}
-    if sites:
-        lic["multisite"] = {"sites": sites}
-    licenses.append(lic)
-    return licenses
-
-
 @lm_cli.command()
-@click.option("--customer_name", required=True, help="name of customer")
-@click.option("--customer_email", required=True, help="customer's email address")
-@click.option("--vendor", required=True, help="vendor name")
-@click.option("--vendor_id", default=None, help="vendor id")
-@click.option("--vendor_email", required=True, help="vendor's email address")
+@click.option("-c", "--customer_name", required=True, help="name of customer")
 @click.option(
+    "-e", "--customer_email", required=True, help="customer's email address"
+)
+@click.option("-vn", "--vendor", required=True, help="vendor name")
+@click.option("-vi", "--vendor_id", default=None, help="vendor id")
+@click.option(
+    "-ve",
+    "--vendor_email",
+    required=True,
+    help="vendor's email address",
+)
+@click.option(
+    "-su",
     "--subscription",
     default=None,
     help="subscription period of dkube license eg. '1y' for 1 "
     "year, '1m' for 1 month, '1w' for 1 week",
 )
-@click.option("--quota", default=None, type=int, help="no of users quota")
-@click.option("--sites", default=None, type=int, help="no of dkube sites")
+@click.option(
+    "-q", "--quota", default=None, type=int, help="no of users " "quota"
+)
+@click.option(
+    "-si", "--sites", default=None, type=int, help="no of dkube " "sites"
+)
 @click.pass_context
 def create_customer(
     ctx,
@@ -98,7 +99,7 @@ def create_customer(
 
 
 @lm_cli.command()
-@click.option("--name", required=True, help="name of the customer")
+@click.option("-n", "--name", required=True, help="name of the customer")
 @click.pass_context
 def get_customer_licenses(ctx, name):
     rc = ctx.obj["rc"]
@@ -106,7 +107,7 @@ def get_customer_licenses(ctx, name):
 
 
 @lm_cli.command()
-@click.option("--id", required=True, help="name of the customer")
+@click.option("--id", "_id", required=True, help="name of the customer")
 @click.pass_context
 def get_customer_licenses_by_id(ctx, _id):
     rc = ctx.obj["rc"]
@@ -114,7 +115,7 @@ def get_customer_licenses_by_id(ctx, _id):
 
 
 @lm_cli.command()
-@click.option("--vendor_id", required=True, help="Vendor Id")
+@click.option("-v", "--vendor_id", required=True, help="Vendor Id")
 @click.pass_context
 def delete_vendor(ctx, vendor_id):
     rc = ctx.obj["rc"]
@@ -122,7 +123,7 @@ def delete_vendor(ctx, vendor_id):
 
 
 @lm_cli.command()
-@click.option("--customer_id", required=True, help="Customer Id")
+@click.option("-c", "--customer_id", required=True, help="Customer Id")
 @click.pass_context
 def delete_customer(ctx, customer_id):
     rc = ctx.obj["rc"]
@@ -144,7 +145,7 @@ def list_vendors(ctx):
 
 
 @lm_cli.command()
-@click.option("--id", required=True, help="Customer Id")
+@click.option("--id", "_id", required=True, help="Customer Id")
 @click.pass_context
 def get_customer(ctx, _id):
     rc = ctx.obj["rc"]
@@ -152,8 +153,8 @@ def get_customer(ctx, _id):
 
 
 @lm_cli.command()
-@click.option("--session_id", required=True, help="Session Id")
-@click.option("--customer_id", help="Customer Id")
+@click.option("-s", "--session_id", required=True, help="Session Id")
+@click.option("-c", "--customer_id", help="Customer Id")
 @click.pass_context
 def clear_session(ctx, session_id, customer_id):
     req = {}
@@ -164,15 +165,20 @@ def clear_session(ctx, session_id, customer_id):
 
 
 @lm_cli.command()
-@click.option("--customer_id", required=True, help="Customer Id")
+@click.option("-c", "--customer_id", required=True, help="Customer Id")
 @click.option(
+    "-su",
     "--subscription",
     default=None,
     help="subscription period of dkube license eg. '1y' for 1 "
     "year, '1m' for 1 month, '1w' for 1 week",
 )
-@click.option("--quota", default=None, type=int, help="no of users quota")
-@click.option("--sites", default=None, type=int, help="no of dkube sites")
+@click.option(
+    "-q", "--quota", default=None, type=int, help="no of users " "quota"
+)
+@click.option(
+    "-si", "--sites", default=None, type=int, help="no of dkube " "sites"
+)
 @click.pass_context
 def update_license(ctx, customer_id, subscription, quota, sites):
     rc = ctx.obj["rc"]
@@ -202,6 +208,12 @@ def logout():
     cfg.close()
 
 
+@lm_cli.command()
+def version():
+    _version = pkg_resources.require("lm-cli")[0].version
+    print(_version)
+
+
 def format_update_license(subscription, quota, sites):
     _license = dict()
     if subscription:
@@ -211,3 +223,15 @@ def format_update_license(subscription, quota, sites):
     if sites:
         _license.update(sites=sites)
     return _license
+
+
+def format_license_input(subscription, quota, sites):
+    licenses, lic = [], {}
+    if subscription:
+        lic["subscription"] = {"time": subscription}
+    if quota:
+        lic["quota"] = {"users": quota}
+    if sites:
+        lic["multisite"] = {"sites": sites}
+    licenses.append(lic)
+    return licenses
